<?php

namespace Drupal\hook_event\Storage;

use Doctrine\Common\Collections\ArrayCollection;
use Drupal\hook_event\Discovery\ApiDiscoveryInterface;

/**
 * Provides the storage wrapper for the discovered hook definitions.
 */
class HookDefinitionStorage implements HookDefinitionStorageInterface {

  /**
   * The API files discovery service.
   *
   * @var \Drupal\hook_event\Discovery\ApiDiscoveryInterface
   */
  protected ApiDiscoveryInterface $apiDiscovery;

  /**
   * Creates the storage instance.
   *
   * @param \Drupal\hook_event\Discovery\ApiDiscoveryInterface $api_discovery
   *   The API files discovery service.
   */
  public function __construct(ApiDiscoveryInterface $api_discovery,) {
    $this->apiDiscovery = $api_discovery;
  }

  /**
   * {@inheritdoc}
   */
  public function getHooksDefinitions(): array {
    return $this->apiDiscovery->getDefinitions();
  }

  /**
   * {@inheritdoc}
   */
  public function getHookDefinition(string $hook): ArrayCollection {
    $definition = $this->getHooksDefinitions()[$hook] ?? [];

    return new ArrayCollection($definition);
  }

  /**
   * {@inheritdoc}
   */
  public function getHookArguments(string $hook): ArrayCollection {
    $arguments = $this->getHookDefinition($hook)->get('arguments') ?? [];

    return new ArrayCollection($arguments);
  }

  /**
   * {@inheritdoc}
   */
  public function hasHookDefinition(string $hook): bool {
    return !$this->getHookDefinition($hook)->isEmpty();
  }

}
